0.2.1 (2022-02-23)
------------------

- Add schemas to properly support bounding_box and compound_bounding_box. [#31]
- Add inputs and outputs to base transform schema to properly document them. [#33]
- Add fixed and bounds to base transform schema to properly document them. [#34]
- Add input_units_equivalencies to base transform schema to properly document it. [#36]
- Add spline1d schema. [#41]
- Add cosine, tangent, arcsine, arccosine, and arctangent schemas. [#40]
- Fix circular build dependencies for asdf. [#38]

0.2.0 (2021-12-13)
------------------

- Remove generic-1.x.0 schemas and examples. [#30]

0.1.0 (2021-11-24)
------------------

- Initial release
